@@ -58,6 +58,8 @@ int globalDebugTimeDelta = 0;
 int globalDebug = 0;
 int globalPid = 0;
 int globalUpdate = 0;
+int passthrough = 0;
+int showBar = 0;   /* Do not display the progress bar. */
 char *globalCreateDb = NULL;
 int failsafe_mode = 0;
 int sig_hup = 0;
@@ -92,7 +94,7 @@ int main(argc, argv, envp)
   gettimeofday(&start_time, NULL);
   progname = argv[0];
   globalPid = getpid();
-  while ((ch = getopt(argc, argv, "hduC:t:c:v")) != EOF)
+  while ((ch = getopt(argc, argv, "hbduPC:t:c:v")) != EOF)
     switch (ch) {
     case 'd':
        globalDebug = 1;
@@ -100,9 +102,14 @@ int main(argc, argv, envp)
     case 'c':
       configFile = optarg;
       break;
+    case 'b':
+      showBar = 1;
     case 'C':
       globalCreateDb = optarg;
       break;
+    case 'P':
+      passthrough = 1;
+      break;
     case 'u':
       globalUpdate = 1;
       break;
@@ -246,14 +253,18 @@ void usage()
 #endif
 {
   fprintf(stderr, 
-	  "Usage: squidGuard [-u] [-C block] [-t time] [-c file] [-v] [-d]\n");
+	  "Usage: squidGuard [-u] [-C block] [-t time] [-c file] [-v] [-d] [-P]\n");
   fprintf(stderr, "Options:\n");
   fprintf(stderr, "  -v          : show version number\n");
   fprintf(stderr, "  -d          : all errors to stderr\n");
+  fprintf(stderr, "  -b          : switch on the progress bar when updating the blacklists\n");
   fprintf(stderr, "  -c file     : load alternate configfile\n");
   fprintf(stderr, "  -t time     : specify startup time in the format: yyyy-mm-ddTHH:MM:SS\n");
   fprintf(stderr, "  -u          : update .db files from .diff files\n");
   fprintf(stderr, "  -C file|all : create new .db files from urls/domain files\n");
   fprintf(stderr, "                specified in \"file\".\n");
+  fprintf(stderr, "  -P          : do not go into emergency mode when an error with the \n");
+  fprintf(stderr, "                blacklists is encountered.\n");
+
   exit(1);
 }
