@@ -144,7 +144,7 @@ int parseLine(line, s)
          strncpy(p+ndx,p+ndx+1, sz);
          p[ndx+sz] = '\0';
           if(1 == report_once) {
-            sgLogError("Warning: Possible bypass attempt. Found multiple slashes where only one is expected: %s", s->orig);
+             sgLogError("Warning: Possible bypass attempt. Found multiple slashes where only one is expected: %s", s->orig); 
             report_once--;
           }
       }
@@ -758,7 +758,18 @@ void sgEmergency ()
 #endif
 {
   char buf[MAX_BUF];
-  sgLogError("going into emergency mode");
+  extern char *globalCreateDb;
+  extern int passthrough;     /* from main.c */
+  if (globalCreateDb == NULL) {
+     if (passthrough == 1) {
+        sgLogError("Warning: Not going into emergency mode because -P was used");
+	fprintf( stderr, "              ****************\n");
+        fprintf( stderr, "FAILURE! Check your log file for problems with the database files!\n" );
+	fprintf( stderr, "              ****************\n");
+        exit(1);
+     }
+  }
+  sgLogError("Going into emergency mode");
   while(fgets(buf, MAX_BUF, stdin) != NULL){
     puts("");
     fflush(stdout);
